@@ -1,7 +1,7 @@
 package Bencher::Scenario::MathPrimeModules;
 
-our $DATE = '2017-01-06'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2017-01-25'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -59,7 +59,7 @@ Bencher::Scenario::MathPrimeModules - Benchmark modules that find prime numbers
 
 =head1 VERSION
 
-This document describes version 0.002 of Bencher::Scenario::MathPrimeModules (from Perl distribution Bencher-Scenario-MathPrimeModules), released on 2017-01-06.
+This document describes version 0.003 of Bencher::Scenario::MathPrimeModules (from Perl distribution Bencher-Scenario-MathPrimeModules), released on 2017-01-25.
 
 =head1 SYNOPSIS
 
@@ -139,33 +139,33 @@ Function call template:
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
+Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) M-5Y71 CPU @ 1.20GHz (2 cores) >>, OS: I<< GNU/Linux LinuxMint version 17.3 >>, OS kernel: I<< Linux version 3.19.0-32-generic >>.
 
 Benchmark with C<< bencher -m MathPrimeModules --exclude-dataset-names 100 >>:
 
  #table1#
- +--------------------------------+-----------+--------+------------+---------+---------+
- | participant                    | rate (/s) |   time | vs_slowest |  errors | samples |
- +--------------------------------+-----------+--------+------------+---------+---------+
- | Acme::PERLANCAR::Prime         |     0.376 | 2.66   |          1 |   0.001 |       6 |
- | Math::Prime::XS::primes        |   120     | 0.0082 |        320 | 2.2e-05 |       6 |
- | Math::Prime::FastSieve::primes |   200     | 0.006  |        500 | 6.3e-05 |       6 |
- | Math::Prime::Util::erat_primes |   280     | 0.0036 |        740 | 2.8e-05 |       6 |
- +--------------------------------+-----------+--------+------------+---------+---------+
+ +--------------------------------+-----------+--------+------------+-----------+---------+
+ | participant                    | rate (/s) |   time | vs_slowest |  errors   | samples |
+ +--------------------------------+-----------+--------+------------+-----------+---------+
+ | Acme::PERLANCAR::Prime         |     0.517 | 1.93   |          1 |   0.001   |       7 |
+ | Math::Prime::XS::primes        |   100     | 0.009  |        200 |   0.00023 |       7 |
+ | Math::Prime::FastSieve::primes |   100     | 0.007  |        300 |   0.00011 |       6 |
+ | Math::Prime::Util::erat_primes |   190     | 0.0052 |        370 | 3.4e-05   |       7 |
+ +--------------------------------+-----------+--------+------------+-----------+---------+
 
 
 Benchmark module startup overhead (C<< bencher -m MathPrimeModules --module-startup >>):
 
  #table2#
- +------------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
- | participant            | proc_private_dirty_size (MB) | proc_rss_size (MB) | proc_size (MB) | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors | samples |
- +------------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
- | Math::Prime::FastSieve | 2.3                          | 5.8                | 28             |      34   |                   28.2 |        1   | 6.6e-05 |       6 |
- | Math::Prime::XS        | 0.82                         | 4.2                | 20             |      22   |                   16.2 |        1.5 | 6.5e-05 |       7 |
- | Math::Prime::Util      | 3.6                          | 7                  | 27             |      21   |                   15.2 |        1.6 | 8.8e-05 |       6 |
- | Acme::PERLANCAR::Prime | 2.5                          | 6.9                | 29             |       9.3 |                    3.5 |        3.7 | 4.7e-05 |       7 |
- | perl -e1 (baseline)    | 0.94                         | 4.3                | 20             |       5.8 |                    0   |        5.9 | 1.8e-05 |       6 |
- +------------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
+ +------------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+-----------+---------+
+ | participant            | proc_private_dirty_size (MB) | proc_rss_size (MB) | proc_size (MB) | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors   | samples |
+ +------------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+-----------+---------+
+ | Math::Prime::FastSieve | 2.3                          | 5.7                | 24             |      33   |                   26.5 |        1   | 9.3e-05   |       8 |
+ | Math::Prime::XS        | 0.82                         | 4.1                | 16             |      23   |                   16.5 |        1.4 | 7.4e-05   |       6 |
+ | Math::Prime::Util      | 3.7                          | 7                  | 23             |      19   |                   12.5 |        1.8 |   0.00018 |       7 |
+ | Acme::PERLANCAR::Prime | 2                            | 6                  | 20             |      10   |                    3.5 |        3   |   0.00011 |       7 |
+ | perl -e1 (baseline)    | 0.94                         | 4.2                | 16             |       6.5 |                    0   |        5.1 | 2.1e-05   |       6 |
+ +------------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+-----------+---------+
 
 
 To display as an interactive HTML table on a browser, you can add option C<--format html+datatables>.
