@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::MathPrimeModules;
 
-our $VERSION = 0.002; # VERSION
+our $VERSION = 0.003; # VERSION
 
 our $results = [
   [
@@ -10,34 +10,34 @@ our $results = [
       {
         errors => 0.001,
         participant => "Acme::PERLANCAR::Prime",
-        rate => 0.376,
-        samples => 6,
-        time => 2.66,
+        rate => 0.517,
+        samples => 7,
+        time => 1.93,
         vs_slowest => 1,
       },
       {
-        errors => 2.2e-05,
+        errors => 0.00023,
         participant => "Math::Prime::XS::primes",
-        rate => 120,
-        samples => 6,
-        time => 0.0082,
-        vs_slowest => 320,
+        rate => 100,
+        samples => 7,
+        time => 0.009,
+        vs_slowest => 200,
       },
       {
-        errors => 6.3e-05,
+        errors => 0.00011,
         participant => "Math::Prime::FastSieve::primes",
-        rate => 200,
+        rate => 100,
         samples => 6,
-        time => 0.006,
-        vs_slowest => 500,
+        time => 0.007,
+        vs_slowest => 300,
       },
       {
-        errors => 2.8e-05,
+        errors => 3.4e-05,
         participant => "Math::Prime::Util::erat_primes",
-        rate => 280,
-        samples => 6,
-        time => 0.0036,
-        vs_slowest => 740,
+        rate => 190,
+        samples => 7,
+        time => 0.0052,
+        vs_slowest => 370,
       },
     ],
     {
@@ -86,6 +86,7 @@ our $results = [
                                                                                 "pbe",
                                                                                 "syscall",
                                                                                 "nx",
+                                                                                "pdpe1gb",
                                                                                 "rdtscp",
                                                                                 "lm",
                                                                                 "constant_tsc",
@@ -108,6 +109,7 @@ our $results = [
                                                                                 "est",
                                                                                 "tm2",
                                                                                 "ssse3",
+                                                                                "fma",
                                                                                 "cx16",
                                                                                 "xtpr",
                                                                                 "pdcm",
@@ -115,16 +117,20 @@ our $results = [
                                                                                 "sse4_1",
                                                                                 "sse4_2",
                                                                                 "x2apic",
+                                                                                "movbe",
                                                                                 "popcnt",
                                                                                 "tsc_deadline_timer",
                                                                                 "aes",
                                                                                 "xsave",
                                                                                 "avx",
+                                                                                "f16c",
+                                                                                "rdrand",
                                                                                 "lahf_lm",
+                                                                                "abm",
+                                                                                "3dnowprefetch",
                                                                                 "ida",
                                                                                 "arat",
                                                                                 "epb",
-                                                                                "xsaveopt",
                                                                                 "pln",
                                                                                 "pts",
                                                                                 "dtherm",
@@ -133,16 +139,30 @@ our $results = [
                                                                                 "flexpriority",
                                                                                 "ept",
                                                                                 "vpid",
+                                                                                "fsgsbase",
+                                                                                "tsc_adjust",
+                                                                                "bmi1",
+                                                                                "hle",
+                                                                                "avx2",
+                                                                                "smep",
+                                                                                "bmi2",
+                                                                                "erms",
+                                                                                "invpcid",
+                                                                                "rtm",
+                                                                                "rdseed",
+                                                                                "adx",
+                                                                                "smap",
+                                                                                "xsaveopt",
                                                                               ],
-                                              L2_cache                     => { max_cache_size => "6144 KB" },
+                                              L2_cache                     => { max_cache_size => "4096 KB" },
                                               manufacturer                 => "GenuineIntel",
-                                              model                        => 42,
-                                              name                         => "Intel(R) Core(TM) i5-2400 CPU \@ 3.10GHz",
-                                              number_of_cores              => 4,
+                                              model                        => 61,
+                                              name                         => "Intel(R) Core(TM) M-5Y71 CPU \@ 1.20GHz",
+                                              number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 0,
-                                              speed                        => 3224.121,
-                                              stepping                     => 7,
+                                              speed                        => 2653.164,
+                                              stepping                     => 4,
                                             },
                                             {
                                               address_width                => 64,
@@ -181,6 +201,7 @@ our $results = [
                                                                                 "pbe",
                                                                                 "syscall",
                                                                                 "nx",
+                                                                                "pdpe1gb",
                                                                                 "rdtscp",
                                                                                 "lm",
                                                                                 "constant_tsc",
@@ -203,6 +224,7 @@ our $results = [
                                                                                 "est",
                                                                                 "tm2",
                                                                                 "ssse3",
+                                                                                "fma",
                                                                                 "cx16",
                                                                                 "xtpr",
                                                                                 "pdcm",
@@ -210,16 +232,20 @@ our $results = [
                                                                                 "sse4_1",
                                                                                 "sse4_2",
                                                                                 "x2apic",
+                                                                                "movbe",
                                                                                 "popcnt",
                                                                                 "tsc_deadline_timer",
                                                                                 "aes",
                                                                                 "xsave",
                                                                                 "avx",
+                                                                                "f16c",
+                                                                                "rdrand",
                                                                                 "lahf_lm",
+                                                                                "abm",
+                                                                                "3dnowprefetch",
                                                                                 "ida",
                                                                                 "arat",
                                                                                 "epb",
-                                                                                "xsaveopt",
                                                                                 "pln",
                                                                                 "pts",
                                                                                 "dtherm",
@@ -228,16 +254,30 @@ our $results = [
                                                                                 "flexpriority",
                                                                                 "ept",
                                                                                 "vpid",
+                                                                                "fsgsbase",
+                                                                                "tsc_adjust",
+                                                                                "bmi1",
+                                                                                "hle",
+                                                                                "avx2",
+                                                                                "smep",
+                                                                                "bmi2",
+                                                                                "erms",
+                                                                                "invpcid",
+                                                                                "rtm",
+                                                                                "rdseed",
+                                                                                "adx",
+                                                                                "smap",
+                                                                                "xsaveopt",
                                                                               ],
-                                              L2_cache                     => { max_cache_size => "6144 KB" },
+                                              L2_cache                     => { max_cache_size => "4096 KB" },
                                               manufacturer                 => "GenuineIntel",
-                                              model                        => 42,
-                                              name                         => "Intel(R) Core(TM) i5-2400 CPU \@ 3.10GHz",
-                                              number_of_cores              => 4,
+                                              model                        => 61,
+                                              name                         => "Intel(R) Core(TM) M-5Y71 CPU \@ 1.20GHz",
+                                              number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 1,
-                                              speed                        => 3193.847,
-                                              stepping                     => 7,
+                                              speed                        => 2853.101,
+                                              stepping                     => 4,
                                             },
                                             {
                                               address_width                => 64,
@@ -276,6 +316,7 @@ our $results = [
                                                                                 "pbe",
                                                                                 "syscall",
                                                                                 "nx",
+                                                                                "pdpe1gb",
                                                                                 "rdtscp",
                                                                                 "lm",
                                                                                 "constant_tsc",
@@ -298,6 +339,7 @@ our $results = [
                                                                                 "est",
                                                                                 "tm2",
                                                                                 "ssse3",
+                                                                                "fma",
                                                                                 "cx16",
                                                                                 "xtpr",
                                                                                 "pdcm",
@@ -305,16 +347,20 @@ our $results = [
                                                                                 "sse4_1",
                                                                                 "sse4_2",
                                                                                 "x2apic",
+                                                                                "movbe",
                                                                                 "popcnt",
                                                                                 "tsc_deadline_timer",
                                                                                 "aes",
                                                                                 "xsave",
                                                                                 "avx",
+                                                                                "f16c",
+                                                                                "rdrand",
                                                                                 "lahf_lm",
+                                                                                "abm",
+                                                                                "3dnowprefetch",
                                                                                 "ida",
                                                                                 "arat",
                                                                                 "epb",
-                                                                                "xsaveopt",
                                                                                 "pln",
                                                                                 "pts",
                                                                                 "dtherm",
@@ -323,16 +369,30 @@ our $results = [
                                                                                 "flexpriority",
                                                                                 "ept",
                                                                                 "vpid",
+                                                                                "fsgsbase",
+                                                                                "tsc_adjust",
+                                                                                "bmi1",
+                                                                                "hle",
+                                                                                "avx2",
+                                                                                "smep",
+                                                                                "bmi2",
+                                                                                "erms",
+                                                                                "invpcid",
+                                                                                "rtm",
+                                                                                "rdseed",
+                                                                                "adx",
+                                                                                "smap",
+                                                                                "xsaveopt",
                                                                               ],
-                                              L2_cache                     => { max_cache_size => "6144 KB" },
+                                              L2_cache                     => { max_cache_size => "4096 KB" },
                                               manufacturer                 => "GenuineIntel",
-                                              model                        => 42,
-                                              name                         => "Intel(R) Core(TM) i5-2400 CPU \@ 3.10GHz",
-                                              number_of_cores              => 4,
+                                              model                        => 61,
+                                              name                         => "Intel(R) Core(TM) M-5Y71 CPU \@ 1.20GHz",
+                                              number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 2,
-                                              speed                        => 2359.269,
-                                              stepping                     => 7,
+                                              speed                        => 2819.578,
+                                              stepping                     => 4,
                                             },
                                             {
                                               address_width                => 64,
@@ -371,6 +431,7 @@ our $results = [
                                                                                 "pbe",
                                                                                 "syscall",
                                                                                 "nx",
+                                                                                "pdpe1gb",
                                                                                 "rdtscp",
                                                                                 "lm",
                                                                                 "constant_tsc",
@@ -393,6 +454,7 @@ our $results = [
                                                                                 "est",
                                                                                 "tm2",
                                                                                 "ssse3",
+                                                                                "fma",
                                                                                 "cx16",
                                                                                 "xtpr",
                                                                                 "pdcm",
@@ -400,16 +462,20 @@ our $results = [
                                                                                 "sse4_1",
                                                                                 "sse4_2",
                                                                                 "x2apic",
+                                                                                "movbe",
                                                                                 "popcnt",
                                                                                 "tsc_deadline_timer",
                                                                                 "aes",
                                                                                 "xsave",
                                                                                 "avx",
+                                                                                "f16c",
+                                                                                "rdrand",
                                                                                 "lahf_lm",
+                                                                                "abm",
+                                                                                "3dnowprefetch",
                                                                                 "ida",
                                                                                 "arat",
                                                                                 "epb",
-                                                                                "xsaveopt",
                                                                                 "pln",
                                                                                 "pts",
                                                                                 "dtherm",
@@ -418,21 +484,36 @@ our $results = [
                                                                                 "flexpriority",
                                                                                 "ept",
                                                                                 "vpid",
+                                                                                "fsgsbase",
+                                                                                "tsc_adjust",
+                                                                                "bmi1",
+                                                                                "hle",
+                                                                                "avx2",
+                                                                                "smep",
+                                                                                "bmi2",
+                                                                                "erms",
+                                                                                "invpcid",
+                                                                                "rtm",
+                                                                                "rdseed",
+                                                                                "adx",
+                                                                                "smap",
+                                                                                "xsaveopt",
                                                                               ],
-                                              L2_cache                     => { max_cache_size => "6144 KB" },
+                                              L2_cache                     => { max_cache_size => "4096 KB" },
                                               manufacturer                 => "GenuineIntel",
-                                              model                        => 42,
-                                              name                         => "Intel(R) Core(TM) i5-2400 CPU \@ 3.10GHz",
-                                              number_of_cores              => 4,
+                                              model                        => 61,
+                                              name                         => "Intel(R) Core(TM) M-5Y71 CPU \@ 1.20GHz",
+                                              number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 3,
-                                              speed                        => 3258.753,
-                                              stepping                     => 7,
+                                              speed                        => 2753.789,
+                                              stepping                     => 4,
                                             },
                                           ],
-      "func.elapsed_time"              => 24.1389200687408,
+      "func.elapsed_time"              => 19.6183841228485,
       "func.module_startup"            => undef,
       "func.module_versions"           => {
+                                            "__PACKAGE__"                         => 1.034,
                                             "Acme::PERLANCAR::Prime"              => 0.001,
                                             "Bencher::Scenario::MathPrimeModules" => undef,
                                             "Benchmark::Dumb"                     => "0.10",
@@ -447,36 +528,36 @@ our $results = [
       "func.permute"                   => ["perl", ["perl"], "participant", [0 .. 3], "dataset", [1]],
       "func.platform_info"             => {
                                             archname => "x86_64",
-                                            codename => "jessie",
+                                            codename => "rosa",
                                             is32bit  => 0,
                                             is64bit  => 1,
-                                            kernel   => "linux-3.16.0-4-amd64",
+                                            kernel   => "linux-3.19.0-32-generic",
                                             kname    => "Linux",
-                                            kvers    => "3.16.0-4-amd64",
+                                            kvers    => "3.19.0-32-generic",
                                             osflag   => "linux",
-                                            oslabel  => "Debian",
+                                            oslabel  => "LinuxMint",
                                             osname   => "GNU/Linux",
-                                            osvers   => "8.0",
+                                            osvers   => 17.3,
                                             source   => {
                                                           "cat /etc/.issue" => "",
-                                                          "cat /etc/issue"  => "Debian GNU/Linux 8 \\n \\l",
-                                                          "lsb_release -a"  => "Distributor ID:\tDebian\nDescription:\tDebian GNU/Linux 8.0 (jessie)\nRelease:\t8.0\nCodename:\tjessie",
-                                                          "uname -a"        => "Linux builder 3.16.0-4-amd64 #1 SMP Debian 3.16.36-1+deb8u2 (2016-10-19) x86_64 GNU/Linux",
+                                                          "cat /etc/issue"  => "Linux Mint 17.3 Rosa \\n \\l",
+                                                          "lsb_release -a"  => "Distributor ID:\tLinuxMint\nDescription:\tLinux Mint 17.3 Rosa\nRelease:\t17.3\nCodename:\trosa",
+                                                          "uname -a"        => "Linux backpacker 3.19.0-32-generic #37~14.04.1-Ubuntu SMP Thu Oct 22 09:41:40 UTC 2015 x86_64 x86_64 x86_64 GNU/Linux",
                                                           "uname -m"        => "x86_64",
                                                           "uname -o"        => "GNU/Linux",
-                                                          "uname -r"        => "3.16.0-4-amd64",
+                                                          "uname -r"        => "3.19.0-32-generic",
                                                           "uname -s"        => "Linux",
                                                         },
                                           },
       "func.precision"                 => 6,
       "func.scenario_module"           => "Bencher::Scenario::MathPrimeModules",
       "func.scenario_module_md5sum"    => "01c119e5cf45999a330d8f03550e2f13",
-      "func.scenario_module_mtime"     => 1483680956,
+      "func.scenario_module_mtime"     => 1483712003,
       "func.scenario_module_sha1sum"   => "3f01fccaf80f99e502c2b930ec4decb641b14cce",
       "func.scenario_module_sha256sum" => "5baf08b6df0a40b231bf0a775f8b843896181d863512617cba04d77405a88663",
-      "func.time_end"                  => 1483681181.97971,
+      "func.time_end"                  => 1485323222.4792,
       "func.time_factor"               => 1,
-      "func.time_start"                => 1483681157.84079,
+      "func.time_start"                => 1485323202.86082,
       "table.field_aligns"             => ["left", "number", "number", "number", "number", "number"],
       "table.field_units"              => [undef, "/s"],
       "table.fields"                   => ["participant", "rate", "time", "vs_slowest", "errors", "samples"],
